![gutta](src/gutta/builder/resources/gutta_logo128.png)

# Gutta - A Webcomic Static Site Builder

**gutta** is a framework to build static websites for webcomics, ready for hosting. It's especially suited to hosting on github.

Learn how to use gutta:

1. [Installation](docs/installation.md)
2. [Creating a new website and using gutta](docs/usage.md)
3. Making the damn thing!
    * [Filling your website with images and other assets](docs/assets.md)
    * [Writing your webcomic.yaml](docs/content.md)
    * [Adding Extra Pages](docs/extras.md)
4. [Styling your website](docs/styling.md)
5. [Publishing your website](docs/publishing.md)


